@@ -32,6 +32,7 @@
 typedef struct {
         DhBookManager *book_manager;
 
+        gchar *current_book_id;
         GList *keyword_words;
         gint   keyword_words_length;
 
@@ -78,6 +79,7 @@ dh_keyword_model_finalize (GObject *object)
 {
         DhKeywordModelPrivate *priv = dh_keyword_model_get_instance_private (DH_KEYWORD_MODEL (object));
 
+        g_free (priv->current_book_id);
         g_list_free (priv->keyword_words);
 
         G_OBJECT_CLASS (dh_keyword_model_parent_class)->finalize (object);
@@ -121,9 +123,10 @@ keyword_model_get_column_type (GtkTreeModel *tree_model,
         switch (column) {
         case DH_KEYWORD_MODEL_COL_NAME:
                 return G_TYPE_STRING;
-                break;
         case DH_KEYWORD_MODEL_COL_LINK:
                 return G_TYPE_POINTER;
+        case DH_KEYWORD_MODEL_COL_CURRENT_BOOK_FLAG:
+                return G_TYPE_BOOLEAN;
         default:
                 return G_TYPE_INVALID;
         }
@@ -187,9 +190,11 @@ keyword_model_get_value (GtkTreeModel *tree_model,
                          gint          column,
                          GValue       *value)
 {
+        DhKeywordModelPrivate *priv;
         DhLink *link;
 
         link = G_LIST (iter->user_data)->data;
+        priv = dh_keyword_model_get_instance_private (DH_KEYWORD_MODEL (tree_model));
 
         switch (column) {
         case DH_KEYWORD_MODEL_COL_NAME:
@@ -200,6 +205,10 @@ keyword_model_get_value (GtkTreeModel *tree_model,
                 g_value_init (value, G_TYPE_POINTER);
                 g_value_set_pointer (value, link);
                 break;
+        case DH_KEYWORD_MODEL_COL_CURRENT_BOOK_FLAG:
+                g_value_init (value, G_TYPE_BOOLEAN);
+                g_value_set_boolean (value, (g_strcmp0 (dh_link_get_book_id (link), priv->current_book_id) == 0));
+                break;
         default:
                 g_warning ("Bad column %d requested", column);
         }
@@ -427,6 +436,7 @@ keyword_model_search_books (DhKeywordModel  *model,
                             const gchar     *string,
                             const GStrv      keywords,
                             const gchar     *book_id,
+                            const gchar     *skip_book_id,
                             const gchar     *page_id,
                             const gchar     *language,
                             gboolean         case_sensitive,
@@ -439,11 +449,12 @@ keyword_model_search_books (DhKeywordModel  *model,
         GList                 *new_list = NULL, *b;
         gint                   hits = 0;
         gchar                 *page_filename_prefix = NULL;
+        GList                 *keyword_globs;
 
         priv = dh_keyword_model_get_instance_private (model);
 
         /* Compile each keyword into a GPatternSpec if necessary */
-        GList *keyword_globs = dh_globbed_keywords_new (keywords);
+        keyword_globs = dh_globbed_keywords_new (keywords);
 
         if (page_id) {
                 page_filename_prefix = g_strdup_printf("%s.", page_id);
@@ -484,6 +495,12 @@ keyword_model_search_books (DhKeywordModel  *model,
                         }
                 }
 
+                /* Skipping a given book? */
+                if (skip_book_id &&
+                    g_strcmp0 (skip_book_id, dh_book_get_name (book)) == 0) {
+                        continue;
+                }
+
                 /* Filtering by language? */
                 if (language &&
                     g_strcmp0 (language, dh_book_get_language (book)) != 0) {
@@ -614,42 +631,99 @@ keyword_model_search (DhKeywordModel  *model,
                       gboolean         case_sensitive,
                       DhLink         **exact_link)
 {
-        guint max_hits = MAX_HITS;
+        guint n_hits_left = MAX_HITS;
         guint n_hits;
-        GList *list;
+        GList *in_book_prefixed = NULL;
+        GList *in_book_non_prefixed = NULL;
+        GList *other_books_prefixed = NULL;
+        GList *other_books_non_prefixed = NULL;
+        DhLink *in_book_exact_link = NULL;
+        DhLink *other_books_exact_link = NULL;
 
-        /* First, look for prefixed items */
-        list = keyword_model_search_books (model,
-                                           string,
-                                           keywords,
-                                           book_id,
-                                           page_id,
-                                           language,
-                                           case_sensitive,
-                                           TRUE,
-                                           max_hits,
-                                           &n_hits,
-                                           exact_link);
-
-        if (n_hits < max_hits) {
-                GList *non_prefixed_list;
+        /* If book_id given; first look for items in the given book id */
+        if (book_id) {
+                /* First, look for prefixed items */
+                n_hits = 0;
+                in_book_prefixed = keyword_model_search_books (model,
+                                                               string,
+                                                               keywords,
+                                                               book_id, NULL,
+                                                               page_id,
+                                                               language,
+                                                               case_sensitive,
+                                                               TRUE,
+                                                               n_hits_left,
+                                                               &n_hits,
+                                                               &in_book_exact_link);
+                n_hits_left -= n_hits;
 
                 /* If not enough hits, get non-prefixed ones */
-                non_prefixed_list = keyword_model_search_books (model,
-                                                                string,
-                                                                keywords,
-                                                                book_id,
-                                                                page_id,
-                                                                language,
-                                                                case_sensitive,
-                                                                FALSE,
-                                                                max_hits - n_hits,
-                                                                NULL,
-                                                                NULL);
-                list = g_list_concat (list, non_prefixed_list);
+                if (n_hits_left > 0) {
+                        n_hits = 0;
+                        in_book_non_prefixed = keyword_model_search_books (model,
+                                                                           string,
+                                                                           keywords,
+                                                                           book_id, NULL,
+                                                                           page_id,
+                                                                           language,
+                                                                           case_sensitive,
+                                                                           FALSE,
+                                                                           n_hits_left,
+                                                                           &n_hits,
+                                                                           NULL);
+                        n_hits_left -= n_hits;
+
+                }
         }
 
-        return list;
+        /* If still room for more items; look for prefixed items in OTHER books */
+        if (n_hits_left > 0) {
+                /* First, look for prefixed items */
+                n_hits = 0;
+                other_books_prefixed = keyword_model_search_books (model,
+                                                                   string,
+                                                                   keywords,
+                                                                   NULL, book_id,
+                                                                   page_id,
+                                                                   language,
+                                                                   case_sensitive,
+                                                                   TRUE,
+                                                                   n_hits_left,
+                                                                   &n_hits,
+                                                                   &other_books_exact_link);
+                n_hits_left -= n_hits;
+
+                /* If not enough hits, get non-prefixed ones */
+                if (n_hits_left > 0) {
+                        other_books_non_prefixed = keyword_model_search_books (model,
+                                                                               string,
+                                                                               keywords,
+                                                                               NULL, book_id,
+                                                                               page_id,
+                                                                               language,
+                                                                               case_sensitive,
+                                                                               FALSE,
+                                                                               n_hits_left,
+                                                                               NULL,
+                                                                               NULL);
+                }
+        }
+
+        /* Prefer in-book exact link */
+        if (in_book_exact_link)
+                *exact_link = in_book_exact_link;
+        else if (other_books_exact_link)
+                *exact_link = other_books_exact_link;
+        else
+                *exact_link = NULL;
+
+        /* Build resulting list */
+        return (g_list_concat (
+                        g_list_concat (
+                                g_list_concat (in_book_prefixed,
+                                               in_book_non_prefixed),
+                                other_books_prefixed),
+                        other_books_non_prefixed));
 }
 
 /* Process the input search string and extract:
@@ -785,15 +859,14 @@ dh_keyword_model_filter (DhKeywordModel *model,
         new_list = NULL;
         hits = 0;
 
-        /* Parse input search string, and make sure either one of the
-         * book ids is set; or both are set and are equal */
+        g_free (priv->current_book_id);
+        priv->current_book_id = NULL;
+
+        /* Parse input search string */
         if (keyword_model_process_search_string (string,
                                                  &book_id_in_string,
                                                  &page_id_in_string,
-                                                 &keywords) &&
-            ((!book_id && book_id_in_string) ||
-             (book_id && !book_id_in_string) ||
-             g_strcmp0 (book_id, book_id_in_string) == 0)) {
+                                                 &keywords)) {
                 gboolean case_sensitive;
 
                 /* Searches are case sensitive when any uppercase
@@ -808,10 +881,13 @@ dh_keyword_model_filter (DhKeywordModel *model,
                         }
                 }
 
+                /* Keep new current book id */
+                priv->current_book_id = g_strdup (book_id_in_string ? book_id_in_string : book_id);
+
                 new_list = keyword_model_search (model,
                                                  string,
                                                  keywords,
-                                                 book_id ? book_id : book_id_in_string,
+                                                 priv->current_book_id,
                                                  page_id_in_string,
                                                  language,
                                                  case_sensitive,
