@@ -43,8 +43,6 @@ typedef struct {
 
         DhLink         *selected_link;
 
-        GtkWidget      *search_all_button;
-        GtkWidget      *search_current_button;
         GtkWidget      *entry;
         GtkWidget      *hitlist;
         GtkWidget      *sw_hitlist;
@@ -86,9 +84,7 @@ sidebar_filter_idle (DhSidebar *sidebar)
 
         str = gtk_entry_get_text (GTK_ENTRY (priv->entry));
 
-        book_link = (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->search_all_button)) ?
-                     NULL :
-                     dh_sidebar_get_selected_book (sidebar));
+        book_link = dh_sidebar_get_selected_book (sidebar);
 
         link = dh_keyword_model_filter (priv->model,
                                         str,
@@ -351,9 +347,6 @@ dh_sidebar_set_search_string (DhSidebar   *sidebar,
 
         priv = dh_sidebar_get_instance_private (sidebar);
 
-        /* Mark "All books" as active */
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->search_all_button), TRUE);
-
         g_signal_handlers_block_by_func (priv->entry,
                                          sidebar_entry_changed_cb,
                                          sidebar);
@@ -390,33 +383,37 @@ search_cell_data_func (GtkTreeViewColumn *tree_column,
 {
         DhLink       *link;
         PangoStyle    style;
+        PangoWeight   weight;
+        gboolean      current_book_flag;
 
         gtk_tree_model_get (tree_model, iter,
                             DH_KEYWORD_MODEL_COL_LINK, &link,
+                            DH_KEYWORD_MODEL_COL_CURRENT_BOOK_FLAG, &current_book_flag,
                             -1);
 
-        style = PANGO_STYLE_NORMAL;
-
         if (dh_link_get_flags (link) & DH_LINK_FLAGS_DEPRECATED)
-                style |= PANGO_STYLE_ITALIC;
+                style = PANGO_STYLE_ITALIC;
+        else
+                style = PANGO_STYLE_NORMAL;
+
+        /* Matches on the current book are given in bold. Note that we check the
+         * current book as it was given to the DhKeywordModel. Do *not* rely on
+         * the current book as given by the DhSidebar, as that will change
+         * whenever a hit is clicked. */
+        if (current_book_flag)
+                weight = PANGO_WEIGHT_BOLD;
+        else
+                weight = PANGO_WEIGHT_NORMAL;
 
         g_object_set (cell,
                       "text", dh_link_get_name (link),
                       "style", style,
+                      "weight", weight,
                       NULL);
 }
 
 /******************************************************************************/
 
-static void
-search_filter_button_toggled (GtkToggleButton *button,
-                              DhSidebar       *sidebar)
-{
-        sidebar_search_run_idle (sidebar);
-}
-
-/******************************************************************************/
-
 static void
 sidebar_book_tree_link_selected_cb (GObject   *ignored,
                                     DhLink    *link,
@@ -492,7 +489,6 @@ dh_sidebar_init (DhSidebar *sidebar)
         DhSidebarPrivate *priv;
         GtkCellRenderer  *cell;
         GtkWidget        *hbox;
-        GtkWidget        *button_box;
 
         priv = dh_sidebar_get_instance_private (sidebar);
 
@@ -527,26 +523,6 @@ dh_sidebar_init (DhSidebar *sidebar)
                           G_CALLBACK (sidebar_entry_text_inserted_cb),
                           sidebar);
 
-        /* Setup the Current/All Files selector */
-        priv->search_current_button = gtk_radio_button_new_with_label (NULL, _("Current"));
-        gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (priv->search_current_button), FALSE);
-        priv->search_all_button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (priv->search_current_button),
-                                                                                     _("All Books"));
-        gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (priv->search_all_button), FALSE);
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->search_all_button), TRUE);
-        g_signal_connect (priv->search_current_button,
-                          "toggled",
-                          G_CALLBACK (search_filter_button_toggled),
-                          sidebar);
-        button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), button_box, FALSE, FALSE, 0);
-        gtk_style_context_add_class (gtk_widget_get_style_context (button_box),
-                                     GTK_STYLE_CLASS_LINKED);
-        gtk_style_context_add_class (gtk_widget_get_style_context (button_box),
-                                     GTK_STYLE_CLASS_RAISED);
-        gtk_box_pack_start (GTK_BOX (button_box), priv->search_current_button, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (button_box), priv->search_all_button, FALSE, FALSE, 0);
-
         /* Setup the hitlist */
         priv->sw_hitlist = gtk_scrolled_window_new (NULL, NULL);
         gtk_widget_set_no_show_all (priv->sw_hitlist, TRUE);
