@@ -24,11 +24,7 @@
 
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
-#else
-#include <webkit/webkit.h>
-#endif
 #include "dh-link.h"
 
 G_BEGIN_DECLS
